@@ -11,26 +11,37 @@ class Future(object):
         self._loop = loop
         self._error = None
         self._result = None
+        self._set_flag = False
         self._timeout = timeout
         self._callback = callback
         self._error_handler = None
         self._result_handler = None
 
     def join(self):
-        while (self._error is None and self._result is None):
+        while (not self._set_flag):
             self._loop.start()
 
     def get(self):
         self.join()
+
+        assert self._set_flag == True
+        if not self._set_flag:
+            # TODO: should be designed error !!
+            raise error.RPCError(128)
+
         if self._result is not None:
             if self._result_handler is None:
                 return self._result
             else:
                 self._result_handler(self._result)
-
-        if self._error_handler is not None:
-            self._error_handler(self._error)
-        raise error.RPCError(self._error)
+        else:
+            if self._error is not None:
+                if self._error_handler is not None:
+                    self._error_handler(self._error)
+                else:
+                    raise error.RPCError(self._error)
+            else:
+                return self._result
 
     def set(self, error=None, result=None):
         self._error = error
@@ -44,16 +55,16 @@ class Future(object):
         return self._result
 
     def set_result(self, result):
-        assert result is not None
         self.set(result=result)
+        self._set_flag = True
 
     @property
     def error(self):
         return self._error
 
     def set_error(self, error):
-        assert error is not None
         self.set(error=error)
+        self._set_flag = True
 
     def attach_callback(self, callback):
         self._callback = callback
